@@ -24,7 +24,11 @@ class Background:
         if overwrite:
             os.system('rm -r {0}'.format(savefolder))
             print('Remove {0}'.format(savefolder))
-        os.system('mkdir {0}'.format(savefolder))
+        tmp = os.getcwd()
+        for i in savefolder.split('/'):
+            os.system('mkdir {0}'.format(i))
+            os.chdir(i)
+        os.chdir(tmp)            
         print('Set savefolder {0}'.format(savefolder))
         # start instantiation
         self.data = {'objname':objname,
@@ -239,7 +243,7 @@ class Background:
         print('Save {0}'.format(string)) 
         # save coef
         coef = self.bkg.model['COEF']
-        norder = bkg.bkg.model['NORDER']
+        norder = self.bkg.model['NORDER']
         tmp = np.full((norder+1,norder+1),fill_value=None,dtype=float)
         for i in coef:
             tmp[i[0],i[1]] = coef[i]
